@@ -16,7 +16,6 @@ import qualified Propellor.Property.Cron as Cron
 import qualified Propellor.Property.Sudo as Sudo
 import qualified Propellor.Property.User as User
 import qualified Propellor.Property.Hostname as Hostname
-import qualified Propellor.Property.Fstab as Fstab
 import qualified Propellor.Property.Tor as Tor
 import qualified Propellor.Property.Dns as Dns
 import qualified Propellor.Property.Git as Git
@@ -26,15 +25,14 @@ import qualified Propellor.Property.LetsEncrypt as LetsEncrypt
 import qualified Propellor.Property.Locale as Locale
 import qualified Propellor.Property.Grub as Grub
 import qualified Propellor.Property.Borg as Borg
-import qualified Propellor.Property.Gpg as Gpg
-import qualified Propellor.Property.OpenId as OpenId
 import qualified Propellor.Property.Systemd as Systemd
 import qualified Propellor.Property.Journald as Journald
 import qualified Propellor.Property.Fail2Ban as Fail2Ban
+import qualified Propellor.Property.FlashKernel as FlashKernel
 import qualified Propellor.Property.Laptop as Laptop
 import qualified Propellor.Property.LightDM as LightDM
+import qualified Propellor.Property.Debootstrap as Debootstrap
 import qualified Propellor.Property.HostingProvider.Linode as Linode
-import qualified Propellor.Property.HostingProvider.DigitalOcean as DigitalOcean
 import qualified Propellor.Property.SiteSpecific.GitHome as GitHome
 import qualified Propellor.Property.SiteSpecific.GitAnnexBuilder as GitAnnexBuilder
 import qualified Propellor.Property.SiteSpecific.Branchable as Branchable
@@ -48,18 +46,17 @@ hosts :: [Host]          --   *             \ | |           '--------'
 hosts =                 --                  (o)  `
 	[ darkstar
 	, dragon
-	, clam
-	, orca
-	, baleen
-	, honeybee
+	, oyster
+	, house
+	, sky
 	, kite
+	, sparrow
 	, beaver
 	, sow
 	, mouse
 	, peregrine
+	, eel
 	, pell
-	, keysafe
-	, quarantimer
 	] ++ monsters
 
 darkstar :: Host
@@ -84,11 +81,8 @@ darkstar = host "darkstar.kitenet.net" $ props
 	& Ssh.userKeys (User "joey") hostContext
 		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICfFntnesZcYz2B2T41ay45igfckXRSh5uVffkuCQkLv joey@darkstar")
 		]
-	& imageBuiltFor honeybee
-		(RawDiskImage "/srv/honeybee.img")
-		(Debootstrapped mempty)
-	! imageBuiltFor banana
-		(RawDiskImage "/srv/banana.img")
+	& imageBuiltFor house
+		(RawDiskImage "/srv/house.img")
 		(Debootstrapped mempty)
 
 dragon :: Host
@@ -97,87 +91,25 @@ dragon = host "dragon.kitenet.net" $ props
 	& JoeySites.dkimMilter
 	& JoeySites.postfixSaslPasswordClient
 
-clam :: Host
-clam = host "clam.kitenet.net" $ props
+oyster :: Host
+oyster = host "oyster.kitenet.net" $ props
 	& standardSystem (Stable "buster") X86_64
 		["Unreliable server. Anything here may be lost at any time!" ]
-	& ipv4 "46.36.36.189"
+	& ipv4 "45.138.157.89"
 
 	& User.hasPassword (User "root")
-	& Ssh.hostKeys hostContext
-		[ (SshEcdsa, "ecdsa-sha2-nistp256 AAAAE2VjZHNhLXNoYTItbmlzdHAyNTYAAAAIbmlzdHAyNTYAAABBBPhfvcOuw0Yt+MnsFc4TI2gWkKi62Eajxz+TgbHMO/uRTYF8c5V8fOI3o+J/3m5+lT0S5o8j8a7xIC3COvi+AVw=")
-		]
 	& Apt.unattendedUpgrades
 
-	-- & Tor.isRelay
-	-- & Tor.named "kite1"
-	-- & Tor.bandwidthRate (Tor.PerMonth "400 GB")
-	
-	& "/etc/resolv.conf" `File.hasContent`
-		[ "nameserver 8.8.8.8"
-		, "nameserver 8.8.4.4"
-		, "nameserver 1.1.1.1"
-		, "domain kitenet.net"
-		, "search kitenet.net"
-		]
-
-baleen :: Host
-baleen = host "baleen.kitenet.net" $ props
-	& standardSystem Unstable X86_64 [ "New git-annex build box." ]
-
-	-- Not on public network; ssh access via bounce host.
-	& ipv4 "138.38.77.40"
-	
-	-- The root filesystem content may be lost if the VM is resized.
-	-- /dev/vdb contains persistent storage.
-	& Fstab.mounted "auto" "/dev/vdb" "/var/lib/container" mempty
-	
-	& Apt.unattendedUpgrades
-	& Postfix.satellite
-	& Apt.serviceInstalledRunning "ntp"
-	& Systemd.persistentJournal
-
-orca :: Host
-orca = host "orca.kitenet.net" $ props
-	& standardSystem Unstable X86_64 [ "Main git-annex build box." ]
-	& ipv4 "138.38.108.179"
-
-	& Apt.unattendedUpgrades
-	& Postfix.satellite
-	& Apt.serviceInstalledRunning "ntp"
-	& Systemd.persistentJournal
-
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		GitAnnexBuilder.standardAutoBuilder
-		Unstable X86_64 Nothing (Cron.Times "15 * * * *") "2h")
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		GitAnnexBuilder.standardAutoBuilder
-		Unstable X86_32 Nothing (Cron.Times "30 * * * *") "2h")
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		GitAnnexBuilder.stackAutoBuilder
-		(Stable "jessie") X86_32 (Just "ancient") (Cron.Times "45 * * * *") "2h")
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		GitAnnexBuilder.standardAutoBuilder
-		Testing ARM64 Nothing (Cron.Times "1 * * * *") "4h")
-
-banana :: Host
-banana = host "banana.kitenet.net" $ props
-	& lemaker_Banana_Pi
-	& hasPartition
-		( partition EXT4
-			`mountedAt` "/"
-			`setSize` MegaBytes 950
-		)
-	& osDebian Testing ARMHF
-	& User.hasInsecurePassword (User "root") "root"
-
-honeybee :: Host
-honeybee = host "honeybee.kitenet.net" $ props
-	& standardSystem Testing ARMHF
-		[ "Home router and arm git-annex build box." ]
+house :: Host
+house = host "house.lan" $ props
+	& standardSystem Testing ARMHF [ "House mail computer." ]
 	& Apt.removed ["rsyslog"]
 	
 	& cubietech_Cubietruck
+	-- fsck when needed on boot
+	& "/etc/default/flash-kernel"
+		`File.containsLine` "LINUX_KERNEL_CMDLINE=\"fsck.repair=yes\""
+		`onChange` FlashKernel.flashKernel
 	& hasPartition
 		( partition EXT3
 			`mountedAt` "/"
@@ -185,8 +117,8 @@ honeybee = host "honeybee.kitenet.net" $ props
 		)
 	& JoeySites.cubieTruckOneWire
 	& Systemd.persistentJournal
-	& Apt.installed ["firmware-misc-nonfree"] -- wifi
-	& Apt.serviceInstalledRunning "ntp" -- no hardware clock
+	& Apt.installed ["firmware-atheros"]
+	& Apt.serviceInstalledRunning "systemd-timesyncd" -- no hardware clock
 	& bootstrappedFrom GitRepoOutsideChroot
 	& Ssh.hostKeys hostContext
 		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIIS/hDYq1MAxfOBf49htym3BOYlx4Gk9SDpiHjv7u6IC")
@@ -200,19 +132,56 @@ honeybee = host "honeybee.kitenet.net" $ props
 		hosts
 		(Context "house.joeyh.name")
 		(SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIMAmVYddg/RgCbIj+cLcEiddeFXaYFnbEJ3uGj9G/EyV joey@honeybee")
-	& JoeySites.homeRouter
+	
+	-- Use iwd to connect to wifi on whatever usb wifi is connected.
+	& Apt.installed ["iwd"]
+	& File.hasContent "/var/lib/iwd/.known_network.freq"
+		[ "[7085c93b-9e5f-5cdb-a13d-bf72db7c3adf]"
+		, "name=/var/lib/iwd//hollow.open"
+		, "list= 2457"
+		]
+	& File.hasContent "/var/lib/iwd/hollow.open"
+		[ "[IPv4]"
+		, "Address=10.1.1.2"
+		, "Netmask=255.255.255.0"
+		, "Gateway=10.1.1.1"
+		, "Broadcast=10.1.1.255"
+		, "DNS=10.1.1.1"
+		]
+	& Systemd.enabled "iwd"
+	& "/etc/resolv.conf" `File.containsLine` "search lan"
+
 	& JoeySites.homeNAS
-	& Apt.installed ["mtr-tiny", "iftop", "screen"]
+	& Apt.installed ["mtr-tiny", "iftop", "screen", "nmap"]
+	-- Currently manually building the xr_usb_serial module.
+	& Apt.installed ["linux-headers-armmp-lpae"]
 	& Postfix.satellite
 
-	& check (not <$> hasContainerCapability Systemd.FilesystemContained) 
-		(setupRevertableProperty autobuilder)
-	-- In case compiler needs more than available ram
-	& Apt.serviceInstalledRunning "swapspace"
+sky :: Host
+sky = host "sky.lan" $ props
+	& standardSystem Testing ARMHF [ "Wifi router." ]
+	& Apt.removed ["rsyslog"]
+	
+	& Apt.installed ["raspi-firmware", "firmware-misc-nonfree"]
+	& Apt.serviceInstalledRunning "systemd-timesyncd" -- no hardware clock
+
+	& Ssh.hostKeys hostContext
+		[ (SshEcdsa, "ecdsa-sha2-nistp256 AAAAE2VjZHNhLXNoYTItbmlzdHAyNTYAAAAIbmlzdHAyNTYAAABBBG19v7K59SzFp/OntM9iyhlKOj2pShFSPJeqR1aiYhPF2NqztcmsY6WvIDqh6jmaISnyV1IqZZ60zvGTVRoOyMY=")
+		]
+	& Ssh.userKeys (User "joey") hostContext
+		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIOmwEfM5qTjA7xuJgygEgHfa1Y/WrRBpu7xBY8D82ul+")
+		]
+
+	& JoeySites.connectStarlinkDish ifs
+	& JoeySites.homeRouter ifs "hollow" JoeySites.hostapd2GhzConfig_mt76
+	& Apt.installed ["mtr-tiny", "iftop", "screen", "nmap", "net-tools"]
+	& Postfix.satellite
   where
-	autobuilder = Systemd.nspawned $ GitAnnexBuilder.autoBuilderContainer
-		(GitAnnexBuilder.armAutoBuilder GitAnnexBuilder.standardAutoBuilder)
-		Testing ARMEL Nothing (Cron.Times "15 15 * * *") "10h"
+	ifs = JoeySites.Interfaces
+		{ JoeySites.ethernetInterface = "eth0"
+		, JoeySites.wifiInterface = "wlan0"
+		, JoeySites.wifiInterfaceOld = "wlan1"
+		}
 
 -- This is not a complete description of kite, since it's a
 -- multiuser system with eg, user passwords that are not deployed
@@ -221,7 +190,10 @@ kite :: Host
 kite = host "kite.kitenet.net" $ props
 	& standardSystemUnhardened Testing X86_64 [ "Welcome to kite!" ]
 	& ipv4 "66.228.36.95"
-	& ipv6 "2600:3c03::f03c:91ff:fe73:b0d2"
+	-- disabled because I've had complaints of mail bouncing, and it
+	-- seems mail servers are only trying ipv6 and then bouncing if
+	-- they have an ipv6 routing issue.
+	-- & ipv6 "2600:3c03::f03c:91ff:fe73:b0d2"
 	& alias "kitenet.net"
 	& Ssh.hostKeys (Context "kitenet.net")
 		[ (SshDsa, "ssh-dss AAAAB3NzaC1kc3MAAACBAO9tnPUT4p+9z7K6/OYuiBNHaij4Nzv5YVBih1vMl+ALz0gYAj8RWJzXmqp5buFAyfgOoLw+H9s1bBS01Sy3i07Dm6cx1fWG4RXL/E/3w1tavX99GD2bBxDBu890ebA5Tp+eFRJkS9+JwSvFiF6CP7NbVjifCagoUO56Ig048RwDAAAAFQDPY2xM3q6KwsVQliel23nrd0rV2QAAAIEAga3hj1hL00rYPNnAUzT8GAaSP62S4W68lusErH+KPbsMwFBFY/Ib1FVf8k6Zn6dZLh/HH/RtJi0JwdzPI1IFW+lwVbKfwBvhQ1lw9cH2rs1UIVgi7Wxdgfy8gEWxf+QIqn62wG+Ulf/HkWGvTrRpoJqlYRNS/gnOWj9Z/4s99koAAACBAM/uJIo2I0nK15wXiTYs/NYUZA7wcErugFn70TRbSgduIFH6U/CQa3rgHJw9DCPCQJLq7pwCnFH7too/qaK+czDk04PsgqV0+Jc7957gU5miPg50d60eJMctHV4eQ1FpwmGGfXxRBR9k2ZvikWYatYir3L6/x1ir7M0bA9IzNU45")
@@ -232,9 +204,8 @@ kite = host "kite.kitenet.net" $ props
 
 	& Network.preserveStatic "eth0" `requires` Network.cleanInterfacesFile
 	& Apt.installed ["linux-image-amd64"]
-	& Apt.serviceInstalledRunning "swapspace"
 	& Linode.serialGrub
-	& Linode.mlocateEnabled
+	& Linode.locateEnabled
 	& Apt.unattendedUpgrades
 	& Systemd.installed
 	& Systemd.persistentJournal
@@ -259,7 +230,6 @@ kite = host "kite.kitenet.net" $ props
 		, "--exclude=/home/joey/lib"
 		-- These directories are backed up and restored separately.
 		, "--exclude=/srv/git"
-		, "--exclude=/var/spool/oldusenet"
 		]
 		[ Borg.KeepDays 7
 		, Borg.KeepWeeks 4
@@ -292,48 +262,37 @@ kite = host "kite.kitenet.net" $ props
 	& Apt.installed
 		[ "git-annex", "myrepos"
 		, "build-essential", "make"
-		, "rss2email", "archivemail"
+		, "rss2email", "chewmail"
 		, "devscripts"
 		-- Some users have zsh as their login shell.
 		, "zsh"
 		]
 
-	& alias "nntp.olduse.net"
-	& JoeySites.oldUseNetServer hosts
-	& Systemd.nspawned oldusenetShellBox
-	
 	& alias "znc.kitenet.net"
 	& JoeySites.ircBouncer
 
 	& alias "kgb.kitenet.net"
 	& JoeySites.kgbServer
 	
-	& Systemd.nspawned ancientKitenet
-	! Systemd.nspawned openidProvider
-	
 	& alias "podcatcher.kitenet.net"
 	& JoeySites.podcatcher
 
-	& JoeySites.scrollBox
-	& alias "scroll.joeyh.name"
-	& alias "us.scroll.joeyh.name"
-
 	& alias "ns4.kitenet.net"
 	& myDnsPrimary "kitenet.net"
 		[ (RelDomain "mouse-onion", CNAME $ AbsDomain "htieo6yu2qtcn2j3.onion")
 		, (RelDomain "beaver-onion", CNAME $ AbsDomain "tl4xsvaxryjylgxs.onion")
 		, (RelDomain "peregrine-onion", CNAME $ AbsDomain "rsdwvaabir6ty2kdzblq7wdda26ib4fuc6hzxzwum75jbn6thqbojvid.onion")
+		, (RelDomain "eel-onion", CNAME $ AbsDomain "4yuc425lsa6ho2c6dlsg4cinadxvsn7vvir7a36ljv7wdyvg52h3inid.onion")
 		, (RelDomain "sow-onion", CNAME $ AbsDomain "urt4g2tq32qktgtp.onion")
 		]
 	& myDnsPrimary "joeyh.name" []
 	& myDnsPrimary "ikiwiki.info" []
-	& myDnsPrimary "olduse.net"
+	! myDnsPrimary "olduse.net"
 		[ (RelDomain "article", CNAME $ AbsDomain "virgil.koldfront.dk")
 		]
-	& myDnsPrimary "quarantimer.app" []
+	! myDnsPrimary "quarantimer.app" []
 	& alias "ns4.branchable.com"
 	& branchableSecondary
-	& Dns.secondaryFor ["animx"] hosts "animx.eu.org"
 	-- Use its own name server (amoung other things this avoids
 	-- spamassassin URIBL_BLOCKED.
 	& "/etc/resolv.conf" `File.hasContent`
@@ -343,13 +302,51 @@ kite = host "kite.kitenet.net" $ props
 		]
 	
 	& alias "debug-me.joeyh.name"
-	& Apt.installed ["debug-me"]
+	& Apt.installed ["debug-me", "debug-me-server"]
 	& Systemd.enabled "debug-me"
 
 	-- testing
 	& Apache.httpsVirtualHost "letsencrypt.joeyh.name" "/var/www/html"
 		(LetsEncrypt.AgreeTOS (Just "id@joeyh.name"))
 	& alias "letsencrypt.joeyh.name"
+	
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		(GitAnnexBuilder.standardAutoBuilder True)
+		Unstable X86_64 mempty Nothing (Cron.Times "15 * * * *") "2h")
+	& Apt.serviceInstalledRunning "swapspace"
+
+sparrow :: Host
+sparrow = host "sparrow.kitenet.net" $ props
+	& standardSystem Testing ARM64 [ "Welcome to sparrow!" ]
+	& ipv4 "128.140.52.168"
+	& ipv6 "2a01:4f8:c17:ed3a::1"
+	& Apt.installed ["ssh"]
+	& Apt.installed [ "git-annex", "myrepos", "build-essential", "make"]
+	-- In case compiler needs more than available ram
+	& Apt.serviceInstalledRunning "swapspace"
+
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		-- qemu hangs running unattended-upgrades on i386
+		-- so disable installing that
+		(GitAnnexBuilder.standardAutoBuilder False)
+		Unstable X86_32 mempty Nothing (Cron.Times "30 * * * *") "4h")
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		GitAnnexBuilder.stackAutoBuilder
+		(Stable "jessie") X86_32 
+		(Debootstrap.UseOldGpgKeyring Debootstrap.:+ Debootstrap.DebootstrapMirror "http://archive.debian.org/debian/")
+		(Just "ancient") (Cron.Times "45 * * * *") "4h")
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		(GitAnnexBuilder.standardAutoBuilder True)
+		Testing ARM64 mempty Nothing (Cron.Times "1 * * * *") "2h")
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		GitAnnexBuilder.stackAutoBuilder
+		(Stable "bullseye") ARM64 mempty
+		(Just "ancient") (Cron.Times "20 * * * *") "2h")
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		(GitAnnexBuilder.armAutoBuilder (GitAnnexBuilder.standardAutoBuilder True))
+		Testing ARMEL mempty Nothing (Cron.Times "15 15 * * *") "2h")
+	
+	& Systemd.nspawned ancientKitenet
 
 beaver :: Host
 beaver = host "beaver.kitenet.net" $ props
@@ -372,6 +369,13 @@ mouse = host "mouse.kitenet.net" $ props
 	& Tor.installed
 	& Tor.hiddenServiceAvailable "ssh" (Port 22)
 
+eel :: Host
+eel = host "eel.kitenet.net" $ props
+	& Apt.installed ["ssh", "screen", "git-annex"]
+	& Tor.installed
+	& Tor.hiddenServiceAvailable "ssh" (Port 22)
+	& LightDM.autoLogin (User "desktop")
+
 peregrine :: Host
 peregrine = host "peregrine.kitenet.net" $ props
 	& Apt.installed ["ssh", "screen", "variety", "git-annex"]
@@ -388,8 +392,6 @@ pell = host "pell.branchable.com" $ props
 
 	-- All the websites I host at branchable that don't use
 	-- branchable.com dns.
-	& alias "olduse.net"
-	& alias "www.olduse.net"
 	& alias "www.kitenet.net"
 	& alias "joeyh.name"
 	& alias "www.joeyh.name"
@@ -408,89 +410,6 @@ pell = host "pell.branchable.com" $ props
 	& Branchable.server hosts
 	& Linode.serialGrub
 
--- See https://joeyh.name/code/keysafe/servers/ for requirements.
-keysafe :: Host
-keysafe = host "keysafe.joeyh.name" $ props
-	& ipv4 "139.59.17.168"
-	& Hostname.sane
-	& Hostname.mailname
-	& osDebian (Stable "buster") X86_64
-	& Apt.stdSourcesList `onChange` Apt.upgrade
-	& Apt.unattendedUpgrades
-	& DigitalOcean.distroKernel
-	-- This is a 500 mb VM, so need more ram to build propellor.
-	& Apt.serviceInstalledRunning "swapspace"
-	& Cron.runPropellor (Cron.Times "30 * * * *")
-	& Apt.installed ["etckeeper", "sudo"]
-	& JoeySites.noExim
-	& Apt.removed ["nfs-common", "rsyslog", "acpid", "rpcbind", "at"]
-
-	& User.hasSomePassword (User "root")
-	& User.accountFor (User "joey")
-	& User.hasSomePassword (User "joey")
-	& Sudo.enabledFor (User "joey")
-
-	& Ssh.installed
-	& Ssh.randomHostKeys
-	& User "root" `Ssh.authorizedKeysFrom` (User "joey", darkstar)
-	& User "joey" `Ssh.authorizedKeysFrom` (User "joey", darkstar)
-	& Ssh.noPasswords
-
-	& Tor.installed
-	& Tor.hiddenServiceAvailable "keysafe" (Port 4242)
-		`requires` Tor.hiddenServiceData "keysafe" hostContext
-	& Tor.bandwidthRate (Tor.PerMonth "750 GB")
-
-	-- keysafe installed manually until package is available
-	& Systemd.enabled "keysafe"
-
-	& Gpg.keyImported (Gpg.GpgKeyId "CECE11AE") (User "root")
-	& Ssh.knownHost hosts "usw-s002.rsync.net" (User "root")
-	& Ssh.userKeys (User "root")
-		(Context "keysafe.joeyh.name")
-		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIEx8bK9ZbXVEgEvxQeXLjnr9cGa/QvoB459aglP529My root@keysafe")
-		]
-	-- Note that this is not an incremental backup; it uploads the
-	-- whole content every time. So, only run weekly.
-	& Cron.niceJob "keysafe backup" Cron.Weekly (User "root") "/" backupcmd
-		`requires` Apt.installed ["rsync"]
-  where
-	datadir = "/var/lib/keysafe"
-	backupdir = "/var/backups/keysafe"
-	rsyncnetbackup = "2318@usw-s002.rsync.net:keysafe"
-	backupcmd = unwords
-		[ "keysafe --store-directory", datadir, "--backup-server", backupdir
-		, "&& rsync -a --delete --max-delete 3 ",  backupdir , rsyncnetbackup
-		]
-
-quarantimer :: Host
-quarantimer = host "quarantimer.app" $ props
-	& ipv4 "45.33.73.207"
-	& Hostname.sane
-	& Hostname.mailname
-	& osDebian (Stable "buster") X86_64
-	& Apt.stdSourcesList `onChange` Apt.upgrade
-	& Apt.unattendedUpgrades
-	& Cron.runPropellor (Cron.Times "30 * * * *")
-	& Apt.installed ["etckeeper", "sudo"]
-	& JoeySites.noExim
-
-	& User.hasSomePassword (User "root")
-	& User.accountFor (User "joey")
-	& User.hasSomePassword (User "joey")
-	& Sudo.enabledFor (User "joey")
-	& Ssh.installed
-	& Ssh.randomHostKeys
-	& User "root" `Ssh.authorizedKeysFrom` (User "joey", darkstar)
-	& User "joey" `Ssh.authorizedKeysFrom` (User "joey", darkstar)
-	& Ssh.noPasswords
-
-	& LetsEncrypt.letsEncrypt (LetsEncrypt.AgreeTOS (Just "id@joeyh.name"))
-		"quarantimer.app" "/home/joey/quarantimer/static"
-	& Apt.installed ["screen", "git", "ghc"]
-	& Apt.installed ["zlib1g-dev", "imagemagick"]
-	-- (Installing quarantimer not yet automated)
-
 
 
        --'                        __|II|      ,.
@@ -504,7 +423,7 @@ quarantimer = host "quarantimer.app" $ props
 -- Exhibit: kite's 90's website on port 1994.
 ancientKitenet :: Systemd.Container
 ancientKitenet = Systemd.debContainer "ancient-kitenet" $ props
-	& standardContainer (Stable "buster")
+	& standardContainer (Stable "buster") ARM64
 	& alias hn
 	& Git.cloned (User "root") "git://kitenet-net.branchable.com/" "/var/www/html"
 		(Just "remotes/origin/old-kitenet.net")
@@ -516,23 +435,6 @@ ancientKitenet = Systemd.debContainer "ancient-kitenet" $ props
 	p = Port 1994
 	hn = "ancient.kitenet.net"
 
-oldusenetShellBox :: Systemd.Container
-oldusenetShellBox = Systemd.debContainer "oldusenet-shellbox" $ props
-	& standardContainer (Stable "buster")
-	& alias "shell.olduse.net"
-	& JoeySites.oldUseNetShellBox
-
--- My own openid provider. Uses php, so containerized for security
--- and administrative sanity.
-openidProvider :: Systemd.Container
-openidProvider = Systemd.debContainer "openid-provider" $ props
-	-- simpleid is not in buster
-	& standardContainer (Stable "stretch")
-	& alias hn
-	& OpenId.providerFor [User "joey", User "liw"] hn (Just (Port 8086))
-  where
-	hn = "openid.kitenet.net"
-
 type Motd = [String]
 
 -- This is my standard system setup.
@@ -565,9 +467,9 @@ standardSystemUnhardened suite arch motd = propertyList "standard system" $ prop
 	& JoeySites.noExim
 
 -- This is my standard container setup, Featuring automatic upgrades.
-standardContainer :: DebianSuite -> Property (HasInfo + Debian)
-standardContainer suite = propertyList "standard container" $ props
-	& osDebian suite X86_64
+standardContainer :: DebianSuite -> Architecture -> Property (HasInfo + Debian)
+standardContainer suite arch = propertyList "standard container" $ props
+	& osDebian suite arch
 	-- Do not want to run mail daemon inside a random container..
 	& JoeySites.noExim
 	& Apt.stdSourcesList `onChange` Apt.upgrade
@@ -597,8 +499,6 @@ monsters =
 		& Ssh.hostPubKey SshEd25519 "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIB7yTEBGfQYdwG/oeL+U9XPMIh/dW7XNs9T+M79YIOrd"
 	, host "ns6.gandi.net" $ props
 		& ipv4 "217.70.177.40"
-	, host "animx" $ props
-		& ipv4 "76.7.174.49"
 	]
 
 
