@@ -2,11 +2,9 @@ module Propellor.Property.Chroot.Util where
 
 import Propellor.Property.Mount
 
-import Utility.Exception
 import Utility.Env
 import Utility.Directory
 
-import System.Directory
 import Control.Applicative
 import Prelude
 
@@ -28,7 +26,3 @@ removeChroot :: FilePath -> IO ()
 removeChroot c = do
 	unmountBelow c
 	removeDirectoryRecursive c
-
--- | Returns true if a chroot directory is empty.
-unpopulated :: FilePath -> IO Bool
-unpopulated d = null <$> catchDefaultIO [] (dirContents d)
