@@ -34,6 +34,9 @@ data DebootstrapConfig
 	| UseEmulation
 	| DebootstrapProxy Url
 	| DebootstrapMirror Url
+	| UseOldGpgKeyring
+	-- ^ Debootstrap using the keyring of old and removed gpg keys.
+	-- This is needed to debootstrap ancient stable releases of Debian.
 	| DebootstrapConfig :+ DebootstrapConfig
 	deriving (Show)
 
@@ -52,6 +55,7 @@ toParams (DebootstrapParam p) = [Param p]
 toParams UseEmulation = []
 toParams (DebootstrapProxy _) = []
 toParams (DebootstrapMirror _) = []
+toParams UseOldGpgKeyring = [Param "--keyring=/usr/share/keyrings/debian-archive-removed-keys.gpg"]
 toParams (c1 :+ c2) = toParams c1 <> toParams c2
 
 useEmulation :: DebootstrapConfig -> Bool
@@ -77,10 +81,6 @@ debootstrapMirror _ = Nothing
 -- When the System is architecture that the kernel does not support,
 -- it can still be bootstrapped using emulation. This is determined
 -- by checking `supportsArch`, or can be configured with `UseEmulation`.
---
--- When emulation is used, the chroot will have an additional binary 
--- installed in it. To get a completelty clean chroot (eg for producing a
--- bootable disk image), use the `removeHostEmulationBinary` property.
 built :: FilePath -> System -> DebootstrapConfig -> Property Linux
 built target system@(System _ targetarch) config =
 	withOS ("debootstrapped " ++ target) go
@@ -116,9 +116,7 @@ built' installprop target system@(System _ arch) config =
 			] ++ case debootstrapMirror config of
 				Just u -> [Param u]
 				Nothing -> []
-		cmd <- if useEmulation config
-			then pure "qemu-debootstrap"
-			else fromMaybe "debootstrap" <$> programPath
+		cmd <- fromMaybe "debootstrap" <$> programPath
 		de <- case debootstrapProxy config of
 			Just u -> addEntry "http_proxy" u <$> standardPathEnv
 			Nothing -> standardPathEnv
