@@ -25,9 +25,14 @@ chainPVGrub :: Grub.TimeoutSecs -> Property (HasInfo + DebianLike)
 chainPVGrub = Grub.chainPVGrub "hd0" "xen/xvda"
 
 -- | Linode disables mlocate's cron job's execute permissions,
--- presumably to avoid disk IO. This ensures it's executable.
-mlocateEnabled :: Property DebianLike
-mlocateEnabled = tightenTargets $
-	"/etc/cron.daily/mlocate"
-		`File.mode` combineModes (readModes ++ executeModes)
-
+-- presumably to avoid disk IO. This ensures it's executable,
+-- if it's installed. It does the same for its replacement plocate,
+-- in cae Linode starts messing with that.
+locateEnabled :: Property DebianLike
+locateEnabled = tightenTargets $
+	propertyList "locate enabled" $ props
+		& go "/etc/cron.daily/mlocate"
+		& go "/etc/cron.daily/plocate"
+  where
+	go f = check (doesFileExist f)
+			(f `File.mode` combineModes (readModes ++ executeModes))
