@@ -7,7 +7,6 @@ import qualified Propellor.Property.File as File
 import qualified Propellor.Property.Apt as Apt
 import qualified Propellor.Property.Service as Service
 import qualified Propellor.Property.ConfFile as ConfFile
-import Utility.FileMode
 import Utility.DataUnits
 
 import System.Posix.Files
@@ -173,20 +172,22 @@ hiddenServiceData hn context = combineProperties desc $ props
   where
 	desc = unwords ["hidden service data available in", varLib </> hn]
 	installonion :: FilePath -> Property (HasInfo + DebianLike)
-	installonion f = withPrivData (PrivFile $ varLib </> hn </> f) context $ \getcontent ->
-		property' desc $ \w -> getcontent $ install w $ varLib </> hn </> f
-	install w f privcontent = ifM (liftIO $ doesFileExist f)
-		( noChange
-		, ensureProperty w $ propertyList desc $ toProps
-			[ property desc $ makeChange $ do
-				createDirectoryIfMissing True (takeDirectory f)
-				writeFileProtected f (unlines (privDataLines privcontent))
-			, File.mode (takeDirectory f) $ combineModes
-				[ownerReadMode, ownerWriteMode, ownerExecuteMode]
-			, File.ownerGroup (takeDirectory f) user (userGroup user)
-			, File.ownerGroup f user (userGroup user)
-			]
-		)
+	installonion basef =
+		let f = varLib </> hn </> basef
+		in withPrivData (PrivFile f) context $ \getcontent ->
+		property' desc $ \w -> getcontent $ \privcontent ->
+			ifM (liftIO $ doesFileExist f)
+				( noChange
+				, ensureProperty w $ propertyList desc $ toProps
+					[ property desc $ makeChange $ do
+						createDirectoryIfMissing True (takeDirectory f)
+						writeFileProtected f (unlines (privDataLines privcontent))
+					, File.mode (takeDirectory f) $ combineModes
+						[ownerReadMode, ownerWriteMode, ownerExecuteMode]
+					, File.ownerGroup (takeDirectory f) user (userGroup user)
+					, File.ownerGroup f user (userGroup user)
+					]
+				)
 
 restarted :: Property DebianLike
 restarted = Service.restarted "tor"
