@@ -14,12 +14,17 @@ module Utility.UserInfo (
 	myUserGecos,
 ) where
 
-import Utility.Env
-import Utility.Data
+import Utility.Env.Basic
 import Utility.Exception
-
-import System.PosixCompat
+#ifndef mingw32_HOST_OS
+import Utility.Data
 import Control.Applicative
+#endif
+
+import System.Posix.User
+#if MIN_VERSION_unix(2,8,0)
+import System.Posix.User.ByteString (UserEntry)
+#endif
 import Prelude
 
 {- Current user's home directory.
@@ -45,8 +50,8 @@ myUserName = myVal env userName
 #endif
 
 myUserGecos :: IO (Maybe String)
--- userGecos crashes on Android and is not available on Windows.
-#if defined(__ANDROID__) || defined(mingw32_HOST_OS)
+-- userGecos is not available on Windows.
+#if defined(mingw32_HOST_OS)
 myUserGecos = return Nothing
 #else
 myUserGecos = eitherToMaybe <$> myVal [] userGecos
@@ -55,9 +60,13 @@ myUserGecos = eitherToMaybe <$> myVal [] userGecos
 myVal :: [String] -> (UserEntry -> String) -> IO (Either String String)
 myVal envvars extract = go envvars
   where
-#ifndef mingw32_HOST_OS
-	go [] = Right . extract <$> (getUserEntryForID =<< getEffectiveUserID)
-#else
-	go [] = return $ Left ("environment not set: " ++ show envvars)
-#endif
+	go [] = either (const $ envnotset) (Right . extract) <$> get
 	go (v:vs) = maybe (go vs) (return . Right) =<< getEnv v
+#ifndef mingw32_HOST_OS
+	-- This may throw an exception if the system doesn't have a
+	-- passwd file etc; don't let it crash.
+	get = tryNonAsync $ getUserEntryForID =<< getEffectiveUserID
+#else
+	get = return envnotset
+#endif
+	envnotset = Left ("environment not set: " ++ show envvars)
